EXPORTS
	??0CT_MsgUtils@@QAE@XZ @ 1 NONAME ; CT_MsgUtils::CT_MsgUtils(void)
	??0CT_MsgUtilsCentralRepository@@QAE@XZ @ 2 NONAME ; CT_MsgUtilsCentralRepository::CT_MsgUtilsCentralRepository(void)
	??0CT_MsgUtilsConfigFileMachineName@@AAE@XZ @ 3 NONAME ; CT_MsgUtilsConfigFileMachineName::CT_MsgUtilsConfigFileMachineName(void)
	??0CT_MsgUtilsConfigFileParserUtility@@AAE@XZ @ 4 NONAME ; CT_MsgUtilsConfigFileParserUtility::CT_MsgUtilsConfigFileParserUtility(void)
	??0CT_MsgUtilsDeleteAllChildren@@QAE@PAVCMsvSession@@J@Z @ 5 NONAME ; CT_MsgUtilsDeleteAllChildren::CT_MsgUtilsDeleteAllChildren(class CMsvSession *, long)
	??0CT_MsgUtilsEnumConverter@@QAE@XZ @ 6 NONAME ; CT_MsgUtilsEnumConverter::CT_MsgUtilsEnumConverter(void)
	?After@CT_MsgTimerUtils@@QAEXHAAVTRequestStatus@@@Z @ 7 NONAME ; void CT_MsgTimerUtils::After(int, class TRequestStatus &)
	?CloseResourceFile@CT_MsgUtils@@SAXPAX@Z @ 8 NONAME ; void CT_MsgUtils::CloseResourceFile(void *)
	?CompareFilesL@CT_MsgUtils@@SAHVTPtrC16@@0HPAV?$CArrayFixFlat@G@@AAH@Z @ 9 NONAME ; int CT_MsgUtils::CompareFilesL(class TPtrC16, class TPtrC16, int, class CArrayFixFlat<unsigned short> *, int &)
	?CompareIapPrefs@CT_MsgUtilsReadEmailSettingsFromConfigFile@@SAHAAVCImIAPPreferences@@0@Z @ 10 NONAME ; int CT_MsgUtilsReadEmailSettingsFromConfigFile::CompareIapPrefs(class CImIAPPreferences &, class CImIAPPreferences &)
	?ConstructL@CT_MsgUtilsConfigFileMachineName@@AAEXABVTDesC16@@@Z @ 11 NONAME ; void CT_MsgUtilsConfigFileMachineName::ConstructL(class TDesC16 const &)
	?ConstructL@CT_MsgUtilsConfigFileParserUtility@@AAEXABVTDesC16@@@Z @ 12 NONAME ; void CT_MsgUtilsConfigFileParserUtility::ConstructL(class TDesC16 const &)
	?ConvertDesToTCommDbDialogPref@CT_MsgUtilsEnumConverter@@SA?AW4TCommDbDialogPref@@AAVTDesC16@@@Z @ 13 NONAME ; enum TCommDbDialogPref CT_MsgUtilsEnumConverter::ConvertDesToTCommDbDialogPref(class TDesC16 &)
	?ConvertDesToTFolderSubscribeType@CT_MsgUtilsEnumConverter@@SA?AW4TFolderSubscribeType@@AAVTDesC16@@@Z @ 14 NONAME ; enum TFolderSubscribeType CT_MsgUtilsEnumConverter::ConvertDesToTFolderSubscribeType(class TDesC16 &)
	?ConvertDesToTFolderSyncType@CT_MsgUtilsEnumConverter@@SA?AW4TFolderSyncType@@AAVTDesC16@@@Z @ 15 NONAME ; enum TFolderSyncType CT_MsgUtilsEnumConverter::ConvertDesToTFolderSyncType(class TDesC16 &)
	?ConvertDesToTImImap4PartialMailOptions@CT_MsgUtilsEnumConverter@@SA?AW4TImImap4PartialMailOptions@@AAVTDesC16@@@Z @ 16 NONAME ; enum TImImap4PartialMailOptions CT_MsgUtilsEnumConverter::ConvertDesToTImImap4PartialMailOptions(class TDesC16 &)
	?ConvertDesToTImSMTPSendCopyToSelf@CT_MsgUtilsEnumConverter@@SA?AW4TImSMTPSendCopyToSelf@@AAVTDesC16@@@Z @ 17 NONAME ; enum TImSMTPSendCopyToSelf CT_MsgUtilsEnumConverter::ConvertDesToTImSMTPSendCopyToSelf(class TDesC16 &)
	?ConvertDesToTImSMTPSendMessageOption@CT_MsgUtilsEnumConverter@@SA?AW4TImSMTPSendMessageOption@@AAVTDesC16@@@Z @ 18 NONAME ; enum TImSMTPSendMessageOption CT_MsgUtilsEnumConverter::ConvertDesToTImSMTPSendMessageOption(class TDesC16 &)
	?ConvertDesToTImap4Cmds@CT_MsgUtilsEnumConverter@@SA?AW4TImap4Cmds@@AAVTDesC16@@@Z @ 19 NONAME ; enum TImap4Cmds CT_MsgUtilsEnumConverter::ConvertDesToTImap4Cmds(class TDesC16 &)
	?ConvertDesToTImap4GetMailOptions@CT_MsgUtilsEnumConverter@@SA?AW4TImap4GetMailOptions@@AAVTDesC16@@@Z @ 20 NONAME ; enum TImap4GetMailOptions CT_MsgUtilsEnumConverter::ConvertDesToTImap4GetMailOptions(class TDesC16 &)
	?ConvertDesToTMsgOutboxBodyEncoding@CT_MsgUtilsEnumConverter@@SA?AW4TMsgOutboxBodyEncoding@@AAVTDesC16@@@Z @ 21 NONAME ; enum TMsgOutboxBodyEncoding CT_MsgUtilsEnumConverter::ConvertDesToTMsgOutboxBodyEncoding(class TDesC16 &)
	?ConvertDesToTPop3Cmds@CT_MsgUtilsEnumConverter@@SA?AW4TPop3Cmds@@ABVTDesC16@@@Z @ 22 NONAME ; enum TPop3Cmds CT_MsgUtilsEnumConverter::ConvertDesToTPop3Cmds(class TDesC16 const &)
	?ConvertDesToTPop3GetMailOptions@CT_MsgUtilsEnumConverter@@SA?AW4TPop3GetMailOptions@@AAVTDesC16@@@Z @ 23 NONAME ; enum TPop3GetMailOptions CT_MsgUtilsEnumConverter::ConvertDesToTPop3GetMailOptions(class TDesC16 &)
	?CreateChildrenSelectionL@CT_MsgUtils@@SAPAVCMsvEntrySelection@@PAVCMsvSession@@J@Z @ 24 NONAME ; class CMsvEntrySelection * CT_MsgUtils::CreateChildrenSelectionL(class CMsvSession *, long)
	?CreateChildrenSelectionRemoteFolderL@CT_MsgUtils@@SAPAVCMsvEntrySelection@@PAVCMsvSession@@VTPtrC16@@1@Z @ 25 NONAME ; class CMsvEntrySelection * CT_MsgUtils::CreateChildrenSelectionRemoteFolderL(class CMsvSession *, class TPtrC16, class TPtrC16)
	?CreateChildrenSelectionRemoteFolderWithTypeL@CT_MsgUtils@@SAPAVCMsvEntrySelection@@PAVCMsvSession@@VTPtrC16@@1VTUid@@@Z @ 26 NONAME ; class CMsvEntrySelection * CT_MsgUtils::CreateChildrenSelectionRemoteFolderWithTypeL(class CMsvSession *, class TPtrC16, class TPtrC16, class TUid)
	?CreateChildrenSelectionWithTypeL@CT_MsgUtils@@SAPAVCMsvEntrySelection@@PAVCMsvSession@@JVTUid@@@Z @ 27 NONAME ; class CMsvEntrySelection * CT_MsgUtils::CreateChildrenSelectionWithTypeL(class CMsvSession *, long, class TUid)
	?FinalProgressStatus@CT_MsgUtilsDeleteAllChildren@@QAEHAAVCMsvOperation@@ABVTRequestStatus@@@Z @ 28 NONAME ; int CT_MsgUtilsDeleteAllChildren::FinalProgressStatus(class CMsvOperation &, class TRequestStatus const &)
	?FindEntryByNameL@CT_MsgUtils@@SAJPAVCMsvEntry@@AAVTDesC16@@1H@Z @ 29 NONAME ; long CT_MsgUtils::FindEntryByNameL(class CMsvEntry *, class TDesC16 &, class TDesC16 &, int)
	?FindEntryByNameL@CT_MsgUtils@@SAJPAVCMsvEntry@@AAVTDesC16@@H@Z @ 30 NONAME ; long CT_MsgUtils::FindEntryByNameL(class CMsvEntry *, class TDesC16 &, int)
	?FindEntryByNameL@CT_MsgUtils@@SAJPAVCMsvSession@@JAAVTDesC16@@1H@Z @ 31 NONAME ; long CT_MsgUtils::FindEntryByNameL(class CMsvSession *, long, class TDesC16 &, class TDesC16 &, int)
	?FindEntryByNameL@CT_MsgUtils@@SAJPAVCMsvSession@@JAAVTDesC16@@H@Z @ 32 NONAME ; long CT_MsgUtils::FindEntryByNameL(class CMsvSession *, long, class TDesC16 &, int)
	?FindFolderIdByName@CT_MsgUtilsEnumConverter@@SAJAAVTDesC16@@@Z @ 33 NONAME ; long CT_MsgUtilsEnumConverter::FindFolderIdByName(class TDesC16 &)
	?GetDefaultSmtpServiceIdL@CT_MsgUtilsCentralRepository@@SAJXZ @ 34 NONAME ; long CT_MsgUtilsCentralRepository::GetDefaultSmtpServiceIdL(void)
	?GetFieldAsInteger@CT_MsgUtilsConfigFileParserUtility@@QAEHABVTDesC16@@AAH@Z @ 35 NONAME ; int CT_MsgUtilsConfigFileParserUtility::GetFieldAsInteger(class TDesC16 const &, int &)
	?GetFieldAsString8@CT_MsgUtilsConfigFileParserUtility@@QAEHABVTDesC16@@AAVTPtrC8@@@Z @ 36 NONAME ; int CT_MsgUtilsConfigFileParserUtility::GetFieldAsString8(class TDesC16 const &, class TPtrC8 &)
	?GetFieldAsString@CT_MsgUtilsConfigFileParserUtility@@QAEHABVTDesC16@@AAVTPtrC16@@@Z @ 37 NONAME ; int CT_MsgUtilsConfigFileParserUtility::GetFieldAsString(class TDesC16 const &, class TPtrC16 &)
	?GetImapAccountL@CT_MsgUtilsCentralRepository@@SAHAAVTDes16@@AAVTImapAccount@@@Z @ 38 NONAME ; int CT_MsgUtilsCentralRepository::GetImapAccountL(class TDes16 &, class TImapAccount &)
	?GetImapServiceIdL@CT_MsgUtilsCentralRepository@@SAJAAVTDes16@@@Z @ 39 NONAME ; long CT_MsgUtilsCentralRepository::GetImapServiceIdL(class TDes16 &)
	?GetPopAccountL@CT_MsgUtilsCentralRepository@@SAHAAVTDes16@@AAVTPopAccount@@@Z @ 40 NONAME ; int CT_MsgUtilsCentralRepository::GetPopAccountL(class TDes16 &, class TPopAccount &)
	?GetPopServiceIdL@CT_MsgUtilsCentralRepository@@SAJAAVTDes16@@@Z @ 41 NONAME ; long CT_MsgUtilsCentralRepository::GetPopServiceIdL(class TDes16 &)
	?GetRemoteFolderIdByNameL@CT_MsgUtils@@SAJPAVCMsvSession@@VTPtrC16@@11H@Z @ 42 NONAME ; long CT_MsgUtils::GetRemoteFolderIdByNameL(class CMsvSession *, class TPtrC16, class TPtrC16, class TPtrC16, int)
	?GetRemoteFolderIdByNameL@CT_MsgUtils@@SAJPAVCMsvSession@@VTPtrC16@@1H@Z @ 43 NONAME ; long CT_MsgUtils::GetRemoteFolderIdByNameL(class CMsvSession *, class TPtrC16, class TPtrC16, int)
	?GetString@CT_MsgUtilsReadEmailSettingsFromConfigFile@@CAHAAVTDesC16@@AAHHAAVTPtrC16@@@Z @ 44 NONAME ; int CT_MsgUtilsReadEmailSettingsFromConfigFile::GetString(class TDesC16 &, int &, int, class TPtrC16 &)
	?MachineName@CT_MsgUtilsConfigFileMachineName@@QAEABVTDesC8@@XZ @ 45 NONAME ; class TDesC8 const & CT_MsgUtilsConfigFileMachineName::MachineName(void)
	?MachineNameEmail@CT_MsgUtilsConfigFileMachineName@@QAEABVTDesC16@@XZ @ 46 NONAME ; class TDesC16 const & CT_MsgUtilsConfigFileMachineName::MachineNameEmail(void)
	?NewL@CT_MsgTimerUtils@@SAPAV1@XZ @ 47 NONAME ; class CT_MsgTimerUtils * CT_MsgTimerUtils::NewL(void)
	?NewL@CT_MsgUtilsConfigFileMachineName@@SAPAV1@ABVTDesC16@@@Z @ 48 NONAME ; class CT_MsgUtilsConfigFileMachineName * CT_MsgUtilsConfigFileMachineName::NewL(class TDesC16 const &)
	?NewL@CT_MsgUtilsConfigFileParserUtility@@SAPAV1@ABVTDesC16@@@Z @ 49 NONAME ; class CT_MsgUtilsConfigFileParserUtility * CT_MsgUtilsConfigFileParserUtility::NewL(class TDesC16 const &)
	?NewLC@CT_MsgUtilsConfigFileMachineName@@SAPAV1@ABVTDesC16@@@Z @ 50 NONAME ; class CT_MsgUtilsConfigFileMachineName * CT_MsgUtilsConfigFileMachineName::NewLC(class TDesC16 const &)
	?OpenResourceFileL@CT_MsgUtils@@SAXAAVRResourceFile@@AAVRFs@@ABVTDesC16@@@Z @ 51 NONAME ; void CT_MsgUtils::OpenResourceFileL(class RResourceFile &, class RFs &, class TDesC16 const &)
	?ReadDataL@CT_MsgUtils@@SAHAAVRFileReadStream@@AAVTPtr16@@HPAV?$CArrayFixFlat@G@@@Z @ 52 NONAME ; int CT_MsgUtils::ReadDataL(class RFileReadStream &, class TPtr16 &, int, class CArrayFixFlat<unsigned short> *)
	?ReadImapIAPAndAddFieldL@CT_MsgUtilsReadEmailSettingsFromConfigFile@@CAXPAVCT_MsgUtilsConfigFileParserUtility@@ABVTDesC16@@AAVCImIAPPreferences@@@Z @ 53 NONAME ; void CT_MsgUtilsReadEmailSettingsFromConfigFile::ReadImapIAPAndAddFieldL(class CT_MsgUtilsConfigFileParserUtility *, class TDesC16 const &, class CImIAPPreferences &)
	?ReadImapIAPAndAddL@CT_MsgUtilsReadEmailSettingsFromConfigFile@@CAXPAVCT_MsgUtilsConfigFileParserUtility@@ABVTDesC16@@AAVCImIAPPreferences@@@Z @ 54 NONAME ; void CT_MsgUtilsReadEmailSettingsFromConfigFile::ReadImapIAPAndAddL(class CT_MsgUtilsConfigFileParserUtility *, class TDesC16 const &, class CImIAPPreferences &)
	?ReadImapSettingsFromConfigurationFileL@CT_MsgUtilsReadEmailSettingsFromConfigFile@@SAXAAVTDesC16@@AAVCImImap4Settings@@AAVCImIAPPreferences@@ABV2@@Z @ 55 NONAME ; void CT_MsgUtilsReadEmailSettingsFromConfigFile::ReadImapSettingsFromConfigurationFileL(class TDesC16 &, class CImImap4Settings &, class CImIAPPreferences &, class TDesC16 const &)
	?ReadPopIAPAndAddFieldL@CT_MsgUtilsReadEmailSettingsFromConfigFile@@CAXPAVCT_MsgUtilsConfigFileParserUtility@@ABVTDesC16@@AAVCImIAPPreferences@@@Z @ 56 NONAME ; void CT_MsgUtilsReadEmailSettingsFromConfigFile::ReadPopIAPAndAddFieldL(class CT_MsgUtilsConfigFileParserUtility *, class TDesC16 const &, class CImIAPPreferences &)
	?ReadPopIAPAndAddL@CT_MsgUtilsReadEmailSettingsFromConfigFile@@CAXPAVCT_MsgUtilsConfigFileParserUtility@@ABVTDesC16@@AAVCImIAPPreferences@@@Z @ 57 NONAME ; void CT_MsgUtilsReadEmailSettingsFromConfigFile::ReadPopIAPAndAddL(class CT_MsgUtilsConfigFileParserUtility *, class TDesC16 const &, class CImIAPPreferences &)
	?ReadPopSettingsFromConfigurationFileL@CT_MsgUtilsReadEmailSettingsFromConfigFile@@SAXAAVTDesC16@@AAVCImPop3Settings@@AAVCImIAPPreferences@@ABV2@@Z @ 58 NONAME ; void CT_MsgUtilsReadEmailSettingsFromConfigFile::ReadPopSettingsFromConfigurationFileL(class TDesC16 &, class CImPop3Settings &, class CImIAPPreferences &, class TDesC16 const &)
	?ReadSmtpIAPAndAddFieldL@CT_MsgUtilsReadEmailSettingsFromConfigFile@@CAXPAVCT_MsgUtilsConfigFileParserUtility@@ABVTDesC16@@AAVCImIAPPreferences@@@Z @ 59 NONAME ; void CT_MsgUtilsReadEmailSettingsFromConfigFile::ReadSmtpIAPAndAddFieldL(class CT_MsgUtilsConfigFileParserUtility *, class TDesC16 const &, class CImIAPPreferences &)
	?ReadSmtpIAPAndAddL@CT_MsgUtilsReadEmailSettingsFromConfigFile@@CAXPAVCT_MsgUtilsConfigFileParserUtility@@ABVTDesC16@@AAVCImIAPPreferences@@@Z @ 60 NONAME ; void CT_MsgUtilsReadEmailSettingsFromConfigFile::ReadSmtpIAPAndAddL(class CT_MsgUtilsConfigFileParserUtility *, class TDesC16 const &, class CImIAPPreferences &)
	?ReadSmtpSettingsFromConfigurationFileL@CT_MsgUtilsReadEmailSettingsFromConfigFile@@SAXAAVTDesC16@@AAVCImSmtpSettings@@AAVCImIAPPreferences@@ABV2@@Z @ 61 NONAME ; void CT_MsgUtilsReadEmailSettingsFromConfigFile::ReadSmtpSettingsFromConfigurationFileL(class TDesC16 &, class CImSmtpSettings &, class CImIAPPreferences &, class TDesC16 const &)
	?SearchMessageBySubjectL@CT_MsgUtils@@SAJPAVCMsvSession@@JVTPtrC16@@@Z @ 62 NONAME ; long CT_MsgUtils::SearchMessageBySubjectL(class CMsvSession *, long, class TPtrC16)
	?StartL@CT_MsgUtilsDeleteAllChildren@@QAEXAAVTRequestStatus@@@Z @ 63 NONAME ; void CT_MsgUtilsDeleteAllChildren::StartL(class TRequestStatus &)
	?ConvertDesToEventCode@CT_MsgUtilsEnumConverter@@SA?AW4TInstrumentationPoint@@AAVTDesC16@@@Z @ 64 NONAME ; enum TInstrumentationPoint CT_MsgUtilsEnumConverter::ConvertDesToEventCode(class TDesC16 &)
	?ConvertDesToTSmtpCmdsL@CT_MsgUtilsEnumConverter@@SA?AW4TSmtpCmds@@AAVTDesC16@@@Z @ 65 NONAME ; enum TSmtpCmds CT_MsgUtilsEnumConverter::ConvertDesToTSmtpCmdsL(class TDesC16 &)
	?SearchMessageBySubjectL@CT_MsgUtils@@SAJPAVCMsvSession@@JVTPtrC16@@H@Z @ 66 NONAME ; long CT_MsgUtils::SearchMessageBySubjectL(class CMsvSession *, long, class TPtrC16, int)
	?ConvertDesToBearerTypes@CT_MsgUtilsEnumConverter@@SAKABVTDesC16@@@Z @ 67 NONAME ; unsigned long CT_MsgUtilsEnumConverter::ConvertDesToBearerTypes(class TDesC16 const &)
	?GetSmtpAccountL@CT_MsgUtilsCentralRepository@@SAHAAVTDes16@@AAVTSmtpAccount@@@Z @ 68 NONAME ; int CT_MsgUtilsCentralRepository::GetSmtpAccountL(class TDes16 &, class TSmtpAccount &)
	?GetSmtpServiceIdL@CT_MsgUtilsCentralRepository@@SAJAAVTDes16@@@Z @ 69 NONAME ; long CT_MsgUtilsCentralRepository::GetSmtpServiceIdL(class TDes16 &)
	?StartL@CT_MsgUtilsDeleteAllChildren@@QAEXHAAVTRequestStatus@@@Z @ 70 NONAME ; void CT_MsgUtilsDeleteAllChildren::StartL(int, class TRequestStatus &)
	?ConvertDesToSearchSortOption@CT_MsgUtilsEnumConverter@@SAHABVTDesC16@@@Z @ 71 NONAME ; int CT_MsgUtilsEnumConverter::ConvertDesToSearchSortOption(class TDesC16 const &)

